#!/bin/bash
set -euo pipefail
export DEBUG=1
export TEST=1
MAILDROPDIR=$(mktemp -d)
cleanup (){
	rm -rf "$MAILDROPDIR"
}
trap cleanup EXIT

export MAILDROPDIR

SCRIPTDIR=$(readlink -e "${BASH_SOURCE[0]%/*}/../")
cd "$MAILDROPDIR"

#
# TEST SIGNUP
set -x
cat <<EOF | while read group alias; do
cropswap@shandan.one Crop Swap Notices
cropswap-members@shandan.one Crop Swap Members
EOF
	mkdir -p "${group}"
	${SCRIPTDIR}/cropswap-postmaster.sh SIGNUP admin@mail.com <<-EOF 1> reply.out 2> reply.err #|| cat reply.err && exit 1
	X-MEMBER-ALIAS: Admin
	X-GROUP-ALIAS: $alias
	X-GROUP: $group
	X-AUTH: admin
	EOF
	contents=$(file reply.out)
	[[ "$contents" =~ empty ]]

	#cat reply.err
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/alist" > "${group}/alist.txt"
	ls ${group} ; cat ${group}/alist.txt
	grep -Fx 'Admin' "${group}/alist.txt" #|| cat "${group}/alist.txt" && exit 1
	grep -Fx 'admin@mail.com' "${group}/alist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh SUBSCRIBE admin@mail.com <<-EOF 1> reply.out 2> reply.err #|| cat reply.err && exit 1
	X-GROUP: $group
	EOF
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep 'You have been successfully subscribed to the Taupiri Crop Swap .* mailing list' reply.out
	grep -Fx 'Admin' "${group}/slist.txt"
	grep -Fx 'admin@mail.com' "${group}/slist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh SUBSCRIBE admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-GROUP: $group
	EOF
	contents=$(file reply.out)
	[[ "$contents" =~ empty ]]

	${SCRIPTDIR}/cropswap-postmaster.sh UNSUBSCRIBE admin@mail.com <<-EOF 1> reply.out 2> reply.err #|| cat reply.err && exit 1
	X-GROUP: $group
	EOF
	grep 'You have been successfully unsubscribed from the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fvx 'Admin' "${group}/slist.txt" || ! grep -Fxq 'Admin' "${group}/slist.txt"
	grep -Fvx 'admin@mail.com' "${group}/slist.txt" || ! grep -Fxq 'admin@mail.com' "${group}/slist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh UNSUBSCRIBE admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-GROUP: $group
	EOF
	contents=$(file reply.out)
	[[ "$contents" =~ empty ]]

	maildrop -f admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [SUBSCRIBE]
	EOF
	grep 'You have been successfully subscribed to the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fx 'Admin' "${group}/slist.txt"
	grep -Fx 'admin@mail.com' "${group}/slist.txt"

	maildrop -f admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [SUBSCRIBE]
	EOF
	grep 'You have been successfully subscribed to the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fx 'Admin' "${group}/slist.txt"
	grep -Fx 'admin@mail.com' "${group}/slist.txt"

	maildrop -f admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [UNSUBSCRIBE]
	EOF
	grep 'You have been successfully unsubscribed from the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fvx 'Admin' "${group}/slist.txt" || ! grep -Fxq 'Admin' "${group}/slist.txt"
	grep -Fvx 'admin@mail.com' "${group}/slist.txt" || ! grep -Fxq 'admin@mail.com' "${group}/slist.txt"

	maildrop -f admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [UNSUBSCRIBE]
	EOF
	grep 'You have been successfully unsubscribed from the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fvx 'Admin' "${group}/slist.txt" || ! grep -Fxq 'Admin' "${group}/slist.txt"
	grep -Fvx 'admin@mail.com' "${group}/slist.txt" || ! grep -Fxq 'admin@mail.com' "${group}/slist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh SIGNUP non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-MEMBER-ALIAS: Non-admin
	X-GROUP-ALIAS: $alias
	X-GROUP: $group
	EOF
	contents=$(file reply.out)
	[[ "$contents" =~ empty ]]
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/alist" > "${group}/alist.txt"
	! grep -Fx 'Non-admin' "${group}/alist.txt"
	! grep -Fx 'non-admin@mail.com' "${group}/alist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh SUBSCRIBE non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-GROUP: $group
	EOF
	grep 'You have been successfully subscribed to the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fx 'Non-admin' "${group}/slist.txt"
	grep -Fx 'non-admin@mail.com' "${group}/slist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh SUBSCRIBE non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-GROUP: $group
	EOF
	contents=$(file reply.out)
	[[ "$contents" =~ empty ]]

	${SCRIPTDIR}/cropswap-postmaster.sh UNSUBSCRIBE non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-GROUP: $group
	EOF
	grep 'You have been successfully unsubscribed from the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fvx 'Non-admin' "${group}/slist.txt" || ! grep -Fqx 'Non-admin' "${group}/slist.txt"
	grep -Fvx 'non-admin@mail.com' "${group}/slist.txt" || ! grep -Fqx 'non-admin@mail.com' "${group}/slist.txt"

	${SCRIPTDIR}/cropswap-postmaster.sh UNSUBSCRIBE non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	X-GROUP: $group
	EOF
	contents=$(file reply.out)
	[[ "$contents" =~ empty ]]

	maildrop -f non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [SUBSCRIBE]
	EOF
	grep 'You have been successfully subscribed to the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fx 'Non-admin' "${group}/slist.txt"
	grep -Fx 'non-admin@mail.com' "${group}/slist.txt"

	maildrop -f non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [SUBSCRIBE]
	EOF
	grep 'You have been successfully subscribed to the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fx 'Non-admin' "${group}/slist.txt"
	grep -Fx 'non-admin@mail.com' "${group}/slist.txt"

	maildrop -f non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [UNSUBSCRIBE]
	EOF
	grep 'You have been successfully unsubscribed from the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fvx 'Non-admin' "${group}/slist.txt" || ! grep -Fxq 'Non-admin' "${group}/slist.txt"
	grep -Fvx 'non-admin@mail.com' "${group}/slist.txt" || ! grep -Fxq 'non-admin@mail.com' "${group}/slist.txt"

	maildrop -f non-admin@mail.com <<-EOF 1> reply.out 2> reply.err
	From: postmaster@localhost
	To: $group
	Subject: [UNSUBSCRIBE]
	EOF
	grep 'You have been successfully unsubscribed from the Taupiri Crop Swap .* mailing list' reply.out
	${SCRIPTDIR}/gdbm-iter-subscribed.py "${group}/mlist" "${group}/slist" > "${group}/slist.txt"
	grep -Fvx 'Non-admin' "${group}/slist.txt" || ! grep -Fxq 'Non-admin' "${group}/slist.txt"
	grep -Fvx 'non-admin@mail.com' "${group}/slist.txt" || ! grep -Fxq 'non-admin@mail.com' "${group}/slist.txt"
done
